clear('all'); close('all'); 
% transient heat conduction in a semi-infinite slab
%
% dT/dt = d^2 T/ dx^2   
% T(x,0) = 0;          0 < x < \infty
% T(0,t) = 1    0 < t
%
% map (0,infty) into (0,1) with 
% z = x/(x+1)   x = z/(1-z)
% T_xx = (T_zz(1-z) -2 T_z)(1-z)^3
%
% jbr, 9/14/2007
%
global z A B alpha

ncol = 50;

[z, A, B, q] = colloc (ncol-1, 'left');

alpha = 1;

% initial condition on temperature
T0  = zeros(ncol, 1);


%choose times for output (see Figure 4.1-2 in BSL, 2002)
time = [0.0, 0.01, 0.1, 1, 10, 100, 1000];

% initial condition is zero except at left end
T0 = zeros(ncol, 1);
T0(1) = 1;

[tout, T] = ode15s (@heateq, time, T0);

% plot T(z) versus z at output times (don't plot intial condition)
figure(1);
plot(z, T(2:end,:), '-o')
axis ([0,1,0,1])

% plot T(x) versus x at output times
x = z./(1-z);
% analytical solution
%xgrid = linspace(0,10,50);
%arg = kron((1./(2*sqrt(time(2:end))))', xgrid);
arg = kron( 1./(2*sqrt(time(2:end)))', x');
Tan = erfc(arg);
figure(2);
plot(x, T(2:end,:), '-o', x, Tan)
axis ([0,10,0,1])

table = [x, T(2:end,:)'];
save -ascii semi_inf.dat table 
